*Preparation of household access and perceptions variables for presentation, asssembles hh-level aggregates  

set more off
set seed 23081920 
set sortseed 11041925

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

use "${gsdData}/1-CleanInput/hh.dta", clear
*include final weights 
drop weight_cons
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match master) keep(match master) nogen keepusing(weight_cons)
order weight_cons, after(weight_adj)

*********************************************************
* Clean access to and quality of services and amenities *
*********************************************************
* house type
recode house_type (1=1 "Apartment") (2 4 = 2 "Shared house/apartment") (3=3 "House") (5/7 1000 = 4 "Hut and other"), gen(house_type_cat)
la var house_type_cat "House categories"

* Drinking water
recode drink_water (1/2=1 "Piped water") (3=2 "Public tap") (4 5 7 9=3 "Borehole,protected well/spring, rainwater collection") (12 10=4 "Tanker-truck, bottled water") (6 8 9 11 13 1000 =5 "Unprotected well/spring, others" )  , gen(water)
recode treat_water (1=0 "No treated water") (2/7 1000 = 1 "Treated water"), gen(treated_water)
replace treated_water = 2 if water!=3
label define treated_water 0 "No treated water" 1 "Treated Water" 2 "Protected water source", replace
la var treated_water "Water treatment among households with unprocted drinking water"
la var water "Drinking water source of household"

* Cooking
recode cooking (1=1 "Wood Stove") (2=2 "Charcoal Stove") (3 4 =3 "Gas Stove") (5 6 = 4 "Electric Stove"), gen(cook)
la var cook "Cooking Source"

************************
* Cleaning Remittances *
************************
* Obtain exchange rates 
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen assert(master match) keepusing(average_er)
* replace missing exchange rate 
egen x=max(average_er) if zone==2
egen av_er_zone1=max(x)
replace average_er=av_er_zone1 if zone==1
gen average_er_thousands=average_er/1000

* convert to USD
gen remit12m_usd=remit12m_amount if remit12m_amount_c==5
replace remit12m_usd=remit12m_amount/average_er if inlist(remit12m_amount_c, 1, 3)
replace remit12m_usd=remit12m_amount/average_er_thousands if inlist(remit12m_amount_c, 2, 4)
drop x av_er_zone1 average_er*
la var remit12m_usd "Remittances in past 12 month, USD amount"

* Cleaning rule 1: winsorize for x<=0.01 and x=>0.99
_pctile remit12m_usd if !missing(remit12m_usd) [pweight=weight_adj], n(100)
replace remit12m_usd = `r(r1)' if remit12m_usd<=`r(r1)' & !missing(remit12m_usd)
replace remit12m_usd = `r(r99)' if remit12m_usd>=`r(r99)' & !missing(remit12m_usd)

* Cleaning rule 2: replace "don't know" and "refused to respond" to median of team
bys team: egen remit12m_team_median = median(remit12m_usd)
replace remit12m_usd = remit12m_team_median if inlist(remit12m_amount_kdk, .a, .b)
drop remit12m_team_median

* drop old regional identifier
drop zone
****************************************
* Generate further indicator variables *
****************************************
* Regional Indicator: Mog, Other Urban, Rural, IDP Camps
gen ind = 1 if team==2 
replace ind = 2 if type==1 & missing(ind)
replace ind = 3 if type==2 
replace ind = 4 if type==3
la def lind 1 "Mogadishu" 2 "Other Urban" 3 "Rural" 4 "IDP Settlements", replace
la val ind lind
la var ind "Indicator: Mogadishu, Other Urban, Rural, IDP Settlements"

********************************
* Labelling for Tables/Figures *
********************************
la var type "Type: Urban, Rural, IDP"
la var health_satisfaction "Satisfaction with Health Access/Clinic"
recode school_satisfaction (0=.)
la var school_satisfaction "Satisfaction with Chilrens's Primary School"
la var employment_opportunities "Employment Opportunities compared to 6 months ago"
la var standard_living "Standard of living prospects"
la var floor_material "Floor material"
la var trust_people "Trust in people"
la var police_competence "Confidence in police protection"
la var safe_walking "Safety walking in neighborhood"
la var travel_other_districts "Safe travelling to other districts"
la var improve_community "Means to improve security"
la var agent_of_change "Agent to improve security"
la var community_disputes "Reason for community disputes"
la var hunger "Hunger in past 4 weeks" 
la var floor_material "Floor material in dwelling"

****************************************
* Merge in aggregates from child files *
****************************************
* add in household member aggregates
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", nogen assert(match) keepusing(penrol penrol_p penrol_s pgender pworking_age pdependent pliteracy hhsize hhh_gender hhh_age hhh_edu lfp_7d_hh emp_7d_hh)
order hhsize, after(weight_cons)
* add in food consumption aggregates
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_fcons.dta", nogen assert(master match) keepusing(opt_mod cons_f0 cons_f1 cons_f2 cons_f3 cons_f4)
order opt_mod cons_f0 cons_f1 cons_f2 cons_f3 cons_f4, after(hhsize) 
* add in nonfood consumption aggregates
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_nfcons.dta", nogen assert(master match) keepusing(cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4)
order cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4, after(cons_f4)
* add in durables aggregates
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_durables.dta", nogen assert(master match) keepusing(cons_d)
order cons_d, after(cons_nf4)
* add in imputed consumption and poverty figures
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match master) keep(match master) nogen keepusing(poorPPP poorPPP_prob tc_imp plinePPP)
order tc_imp poorPPP_prob poorPPP, after(weight_cons)
label define lpoorPPP 0 "Non-Poor" 1 "Poor", replace
label values poorPPP lpoorPPP

*******************************
* Generate Poverty Statistics *
*******************************
*Poverty Gap Index
gen pgi = (plinePPP - tc_imp)/plinePPP if !mi(tc_imp) & tc_imp < plinePPP
replace pgi = 0 if tc_imp>plinePPP & !mi(tc_imp)
la var pgi "Poverty Gap Index"

* Poverty Severity
gen pseverity = pgi^2
la var pseverity "Poverty Severity/Squared Poverty Gap"

order tc_imp poorPPP pgi pseverity, after(hhsize)

********************
* Create Quintiles *
********************
* Based on total consumption (Imputed)
xtile quintiles_tc = tc_imp [pweight=weight_cons*hhsize], n(5) 
label define lquintiles_tc 1 "Q1 (bottom 20)"	2 "Q2"	3 "Q3"	4 "Q4"	5 "Q5 (top 20)"
label values quintiles_tc lquintiles_tc
label var quintiles_tc "Consumption Quintiles per capita based on total imputed consumption"
save "${gsdData}/1-CleanTemp/hh.dta", replace

********************
*  Arrange assets  *
********************
use "${gsdData}/1-CleanTemp/assets.dta", clear
drop weight_cons
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match master) keep(match master) nogen keepusing(weight_cons)
order strata ea block hh team astrata type weight_cons
order cons_d cf_median cons_flow drate drate_median own_median, after(itemid)
label var astrata "Analytical strata"
save "${gsdData}/1-CleanOutput/assets.dta", replace

*************************************************
* Include imputed consumption into the datasets *
*************************************************
use "${gsdData}/1-CleanTemp/hh.dta", clear
*create a file with imputed consumption (pc pd curr USD) in long format
foreach cat in f nf {
	use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
	keep strata ea block hh weight_cons hhsize opt_mod mi_cons_`cat'0 mi_cons_`cat'1 mi_cons_`cat'2 mi_cons_`cat'3 mi_cons_`cat'4 
    ren (mi_cons_`cat'*) (x*)
    reshape long x, i(strata ea block hh) j(mod_item)
    ren x mi_cons_`cat'
	*include data in the same units (current USD per hh per week)
	replace mi_cons_`cat'=mi_cons_`cat'*hhsize*7	
    save "${gsdTemp}/mi_`cat'_collapsed.dta", replace
}
*rename files to be used in other loops 
use "${gsdTemp}/mi_f_collapsed.dta", clear
rename mi_cons_f mi_cons_food
save "${gsdTemp}/mi_food_collapsed.dta", replace
use "${gsdTemp}/mi_nf_collapsed.dta", clear
rename mi_cons_nf mi_cons_nonfood
save "${gsdTemp}/mi_nonfood_collapsed.dta", replace

*prepare clean food and non-food datasets to loop over food and non-food
use "${gsdData}/1-CleanTemp/food.dta", clear
save "${gsdTemp}/food.dta", replace
use "${gsdData}/1-CleanTemp/nonfood.dta", clear
rename pr_usd cons_usd
*include the 206 households with zero non-food consumption 
append using "${gsdTemp}/nfood_hhs_with_zerocons.dta"
replace itemid=1001 if itemid>=.
save "${gsdTemp}/nonfood.dta", replace

*create a file with all the items for all the households & obtain shares 
set sortseed 11041925
foreach cat in food nonfood {
	use "${gsdTemp}/`cat'.dta", clear
	keep strata ea block hh weight_cons opt_mod itemid mod_item cons_usd
	reshape wide mod_item cons_usd , i(strata ea block hh opt_mod) j(itemid) 
	reshape long mod_item cons_usd, i(strata ea block hh opt_mod) j(itemid) 
	*include module of each item
	drop mod_item
	merge m:1 itemid using "${gsdData}/1-CleanTemp/items_module_`cat'.dta", keep(match) nogen keepusing(mod_item) 
	save "${gsdTemp}/dataset_`cat'.dta", replace
	*next we obtain the consumption share of each item
	collapse (sum) cons_usd (max) mod_item, by(itemid)	
	bys mod_item: egen cons_usd_tot=sum(cons_usd)
	gen share_`cat'=cons_usd/cons_usd_tot
	save "${gsdTemp}/shares_`cat'.dta", replace
}

*continue merging the previous files, allocating imputed consumption and dropping/rescaling small values
set sortseed 11041925
foreach cat in food nonfood {
	use "${gsdTemp}/dataset_`cat'.dta", clear
	merge m:1 itemid using "${gsdTemp}/shares_`cat'.dta", assert(match) nogen keepusing(share_`cat')
	merge m:1 strata ea block hh mod_item using "${gsdTemp}/mi_`cat'_collapsed.dta", assert(match) nogen keepusing(mi_cons_`cat') 
	*include hh size and order the dataset
	merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh.dta", keep(match) nogen keepusing(hhsize)
	order strata ea block hh weight_cons hhsize opt_mod itemid mod_item cons_usd share_`cat' mi_cons_`cat'
	*obtain the imputed consumption per household per item (pc pd curr USD)
	gen mi_cons_value = . 
	replace mi_cons_value  = share_`cat' * mi_cons_`cat' if mod_item!=0 & opt_mod!=mod_item
    replace mi_cons_value  = cons_usd if mod_item==0 | opt_mod==mod_item
    replace mi_cons_value  = 0 if mi_cons_value>=.

	*check that the imputed consumption by item sums up to the module aggregate
	preserve
	ren mi_cons_value sumcheck
	collapse (first) mi_cons_`cat' (sum) sumcheck, by(strata ea block hh mod_item )
    assert round(mi_cons_`cat' - sumcheck ,.001)==0 if (!missing(mi_cons_`cat'))
    restore	
	*check that the consumption share of each item is still the same 
	preserve
	collapse (sum) mi_cons_value (max) mod_item, by(itemid)	
	bys mod_item: egen mi_cons_tot=sum(mi_cons_value)
	gen share_`cat'_after=mi_cons_value/mi_cons_tot
	merge 1:1 itemid using "${gsdTemp}/shares_`cat'.dta", assert(match) nogen keepusing(share_`cat')
	assert round(share_`cat'_after)==round(share_`cat')
	restore

	*generate a flag for imputed values 
	gen imputed = 1 if (opt_mod!=mod_item & mod_item >0) 
	replace imputed=0 if imputed>=.
	label define limputed 0 "Consumption value collected" 1 "Consumption value imputed"
	label values imputed limputed
	label var imputed "Dummy indicating if consumption value was collected or imputed"

	*organize the dataset
	drop share_`cat' mi_cons_`cat'
	ren (cons_usd mi_cons_value) (cons_usd_original cons_usd_final)
	label var cons_usd_original "Consumption (collected only) in current USD (7 days)"
	assert cons_usd_original>=. if imputed == 1

	*drop items with zero or very small consumption (<0.0005 approx. 1.6 SSh per hh per day) for non-collected data & rescale the other items
	gen small =1 if cons_usd_final< 0.0005 & mod_item!=0 & opt_mod!=mod_item	
	replace small = 0 if small==.
	bys strata ea block hh: egen sum = sum(cons_usd_final) 
	bys strata ea block hh: egen x= sum(cons_usd_final) if small == 1
	bys strata ea block hh: egen y= sum(cons_usd_final) if small == 0 
	*distribute to all records
	bys strata ea block hh: egen small_sum = max(x)
	bys strata ea block hh: egen nonsmall_sum= max(y)
	drop x y
	*obtain the factor to scale consumption values 
	gen factor= cons_usd_final / nonsmall_sum 
    gen scaled_cons = cons_usd_final + (factor * small_sum) if small_sum<.
	replace scaled_cons=cons_usd_final if small_sum>=.
	*check that the rescaling was included correctly, organize and save the dataset
	bys strata ea block hh: egen sum_scaled_cons = sum(scaled_cons)
	assert scaled_cons==cons_usd_final if small_sum>=.
	assert round(sum_scaled_cons - sum,.001)==0 if sum_scaled_cons!=0 & small_sum>=.
	drop cons_usd_final
	ren  scaled_cons cons_usd_final
	drop sum small_sum nonsmall_sum factor sum_scaled_cons
	order cons_usd_final, after(cons_usd_original)
	label var cons_usd_final "Consumption (imputed + collected) in current USD (7 days)"
	save "${gsdData}/1-CleanTemp/imputed_`cat'_byitem.dta", replace

}

*integrate into the final dataset for food consumption
use "${gsdData}/1-CleanTemp/food.dta", replace
merge 1:1 strata ea block hh itemid using "${gsdData}/1-CleanTemp/imputed_food_byitem.dta", assert(match using) nogen
drop if small == 1
drop cons_usd small
order hhsize, after(weight_cons)
order team, after(hh)
order cons_usd_original cons_usd_final imputed, after(mod_item)
order astrata type, after(weight_cons)
*distribute some variables to all records
qui foreach i in team astrata type { 
	bys strata ea block hh: egen `i'_all=max(`i')
	replace `i'=`i'_all if `i'>=.
	drop `i'_all
}   
label var astrata "Analytical Strata"
*label items as non-administered
foreach var of varlist pr_usd-purc_p_tag {
   replace `var'=.z if imputed==1
}
sort strata ea block hh

*correctly code each variable 
*items in the core should have a zero or positive value and not missing
replace cons_usd_original=0 if cons_usd_original>=. & mod_item==0
replace cons_usd_final=0 if cons_usd_original==0 & mod_item==0
*items in the administered module should have a zero or positive value and not missing
replace cons_usd_original=0 if cons_usd_original>=. & mod_item==opt_mod
replace cons_usd_final=0 if cons_usd_original==0 & mod_item==opt_mod
*items in the non-admin module should be coded as such
replace cons_usd_original=.z if cons_usd_original>=. & opt_mod!=mod_item & mod_item!=0
*check imputed equals collected for the core and assinged modules 
assert round(cons_usd_original-cons_usd_final,.01)==0 if imputed==0
*other checks for consistency
assert cons_usd_original>=. if opt_mod!=mod_item & mod_item!=0
assert imputed==1 if opt_mod!=mod_item & mod_item!=0
assert imputed==0 if opt_mod==mod_item | mod_item==0
assert cons_usd_original==.z if imputed==1
assert cons_usd_final>0 if imputed==1
assert cons_usd_original== cons_usd_final & cons_usd_final==0 if cons==.
*include the correct weight for consumption data 
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match) nogen keepusing(weight_cons)
order weight_cons, after(type)
label var weight_cons "HH weights (adjusted bottom 25%)"
*clarify responses with "Dont't know" or "Refused to respond"
replace imputed=2 if cons==.a | cons==.b 
label define limputed 2 "Cons value assigned w/mean (including zeros) of closest area", modify
save "${gsdData}/1-CleanOutput/food.dta", replace

*correctly consider all values as imputed for the 206 hhs in non-food w/zero non-food cons
use "${gsdTemp}/nfood_hhs_with_zerocons.dta", clear
gen imputed_correct=1 
save "${gsdTemp}/nfood_mi_hhs_zerocons.dta", replace
use "${gsdData}/1-CleanTemp/imputed_nonfood_byitem.dta", clear
merge m:1 strata ea block hh using "${gsdTemp}/nfood_mi_hhs_zerocons.dta", keep (master match) nogen keepusing(imputed_correct) 
replace imputed_correct=0 if mod_item==0 & imputed_correct==1
replace imputed_correct=0 if mod_item==opt_mod & imputed_correct==1
replace imputed=imputed_correct if imputed_correct<.
drop imputed_correct
save "${gsdData}/1-CleanTemp/imputed_nonfood_byitem.dta", replace

*integrate into the final dataset for non-food consumption (including 206 hhs)
use "${gsdData}/1-CleanTemp/nonfood.dta", clear
merge 1:1 strata ea block hh itemid using "${gsdData}/1-CleanTemp/imputed_nonfood_byitem.dta", assert(match using) nogen
drop if small == 1
drop pr_usd small
order cons_usd_original cons_usd_final imputed, after(mod_item)
rename (cons_usd_original cons_usd_final) (purc_usd_original purc_usd_final)
label var purc_usd_final "Purchase value (imputed + collected) in current USD (7 days)"
label var purc_usd_original "Purchase value (collected only) in current USD (7 days)"
*include team astrata type 
drop team astrata type
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh.dta", nogen keep(match master) keepusing(team astrata type)
order hhsize, after(weight_cons)
order team, after(hh)
order astrata type, after(weight_cons)
*include the correct recall period 
drop recall_d 
rename itemid nfoodid
merge m:1 nfoodid using "${gsdData}/1-CleanInput/recall_days.dta", nogen keep(match master)
rename nfoodid itemid
order recall_d, after(itemid)
order mod_item, before(itemid)
label var astrata "Analytical Strata"
*label items as non-administered
foreach var of varlist purc-purc_tag {
   replace `var'=.z if imputed==1
}
*correct for the 206 hhs as not every item was not administered 
merge m:1 strata ea block hh using "${gsdTemp}/nfood_hhs_with_zerocons.dta", keep(master match)
foreach var of varlist purc-purc_tag {
   replace `var'=. if _merge==3 & (opt_mod==mod_item | mod_item==0)
}
drop _merge
sort strata ea block hh

*correctly code each variable 
*items in the core should have a zero or positive value and not missing
replace purc_usd_original=0 if purc_usd_original>=. & mod_item==0
replace purc_usd_final=0 if purc_usd_original==0 & mod_item==0
*items in the administered module should have a zero or positive value and not missing
replace purc_usd_original=0 if purc_usd_original>=. & mod_item==opt_mod
replace purc_usd_final=0 if purc_usd_original==0 & mod_item==opt_mod
*items in the non-admin module should be coded as such
replace purc_usd_original=.z if purc_usd_original>=. & opt_mod!=mod_item & mod_item!=0
*check imputed equals collected for the core and assinged modules 
assert round(purc_usd_original-purc_usd_final,.01)==0 if imputed==0
*other checks for consistency
assert purc_usd_original>=. if opt_mod!=mod_item & mod_item!=0
assert imputed==1 if opt_mod!=mod_item & mod_item!=0
assert imputed==0 if opt_mod==mod_item | mod_item==0
assert purc_usd_original==.z if imputed==1
assert purc_usd_final>0 if imputed==1
assert purc_usd_original==purc_usd_final & purc_usd_final==0 if purc==.
*include the correct weight for consumption data 
merge m:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match) nogen keepusing(weight_cons)
order weight_cons, after(type)
label var weight_cons "HH weights (adjusted bottom 25%)"
*clarify responses with "Dont't know" or "Refused to respond"
replace imputed=2 if purc==.a | purc==.b 
label define limputed 2 "Cons value assigned w/mean (including zeros) of closest area", modify
save "${gsdData}/1-CleanOutput/nonfood.dta", replace

*integrate into the household dataset 
*first collapse food and non-food at the hh level
use "${gsdData}/1-CleanOutput/food.dta", clear
collapse (sum) cons_usd_final, by(strata ea block hh opt_mod mod_item)
reshape wide cons_usd, i(strata ea block hh opt_mod) j(mod_item)
save "${gsdData}/1-CleanTemp/imputed_food_byhh.dta", replace
use "${gsdData}/1-CleanOutput/nonfood.dta", clear
collapse (sum) purc_usd_final, by(strata ea block hh opt_mod mod_item)
reshape wide purc_usd, i(strata ea block hh opt_mod) j(mod_item)
save "${gsdData}/1-CleanTemp/imputed_nonfood_byhh.dta", replace
*then retrive the hh dataset, rename variables and include imputed consumption
use "${gsdData}/1-CleanTemp/hh.dta", clear
forvalues i = 0/4 {
 label var cons_f`i' "Food consumption (collected only) in current USD (Mod:`i'): 7d"
 rename cons_f`i' cons_f`i'_original
}
forvalues i = 0/4 {
 label var cons_nf`i' "Non-Food consumption (collected only) in current USD (Mod:`i'): 7d"
 rename cons_nf`i' cons_nf`i'_original
}
*include food consumption
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/imputed_food_byhh.dta", assert(match master) nogen 	
rename (cons_usd_final0 cons_usd_final1 cons_usd_final2 cons_usd_final3 cons_usd_final4) (cons_f0 cons_f1 cons_f2 cons_f3 cons_f4 )
forvalues i = 0/4 {
 label var cons_f`i' "Food consumption (imputed + collected) in current USD (Mod:`i'): 7d"
 rename cons_f`i' cons_f`i'_final
}

*include non-food consumption 
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/imputed_nonfood_byhh.dta", assert(match master) nogen 	
rename (purc_usd_final0 purc_usd_final1 purc_usd_final2 purc_usd_final3 purc_usd_final4) (cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4 )
forvalues i = 0/4 {
 label var cons_nf`i' "Non-Food cons (imputed + collected) in current USD (Mod:`i'): 7d"
 rename cons_nf`i' cons_nf`i'_final
}
*organize the dataset 
label var astrata "Analytical Strata"
order team, after(hh)
order cons_f0_final cons_f1_final cons_f2_final cons_f3_final cons_f4_final, after (cons_d)
order cons_nf0_final cons_nf1_final cons_nf2_final cons_nf3_final cons_nf4_final, after (cons_f4_final)
order poorPPP_prob poorPPP plinePPP quintiles_tc, after (weight_cons)

*finally, include imputed consumption of durables 
merge 1:1 strata ea block hh using  "${gsdData}/1-CleanTemp/hhq-poverty.dta", assert(match master) nogen keepusing(mi_cons_d)	
rename mi_cons_d cons_d_final
order cons_d_final, after (cons_nf4_final)
rename cons_d cons_d_original
label var cons_d_original "Consumption flow of durables (collected only) in current USD: 7d" 
label var cons_d_final "Consumption flow of durables (imputed + collected) in current USD: 7d" 
label var l_totalsales_val  "M.121 In fiscal year 2014-15, establishment’s total annual sales"
foreach var of varlist tc_imp-cons_d_final {
	replace `var'=.c if weight_cons>=. & `var'>=.
}
foreach var of varlist cons_f0_final-cons_nf4_final {
	replace `var'=.c if opt_mod==.
    replace `var'=0 if `var'==.
}
*order the variables and final arrangements 
drop hhs_tot_astrata hhs_master_sample tot_hhweight check
order strata ea block hh team enum ind astrata reg_pess hhsize weight weight_adj weight_cons
order plinePPP, after(tc_imp)
order type, after(astrata)
drop cons_f0_original-cons_d_original
egen tc_imp_f=rowtotal(cons_f0_final-cons_f4_final)
label var tc_imp_f "Total Food cons (imputed + collected) in current USD: 7d"
egen tc_imp_nf=rowtotal(cons_nf0_final-cons_nf4_final)
label var tc_imp_nf "Total Non-Food cons (imputed + collected) in current USD: 7d"
gen tc_imp_d=cons_d_final
label var tc_imp_d "Consumption flow of durables (imputed + collected) in current USD: 7d"
order tc_imp_f tc_imp_nf tc_imp_d, after(tc_imp)
drop cons_f0_final-cons_d_final
order house_type_cat, after( house_type)
order water, after(drink_water) 
order treated_water, after(treat_water) 
order cook, after(cooking)
order remit12m_usd , after(remit12m)
order hhh_gender hhh_age hhh_edu, after(hhh_id)
order penrol_p penrol_s pgender pworking_age pdependent pliteracy lfp_7d_hh emp_7d_hh, after(hhh_edu)
order hhsize, after(opt_mod)
order plinePPP, after(weight_cons)
order penrol, after(penrol_s)

*************************
* Declare survey & save *
*************************
svyset ea [pweight=weight], strata(strata)
save "${gsdData}/1-CleanOutput/hh.dta", replace
