* Purpose: create descriptive statistics for presentation

set more off
set seed 23081980 
set sortseed 11041955

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

********************************************************************************
*****                                                                      *****
*****                           SAMPLE                                     *****
*****                                                                      *****
********************************************************************************


**************************** SHEET 0 - Sample Size *****************************
********************************************************************************
* Sample Size
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_cons], strata(strata)

*Sample size (households) by state & urban/rural status
tabout ind  using "${gsdOutput}/Som_Presentation_0.xls", c(freq) replace
*Sample size (households) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", c(freq)  append

*Population size (households) by urban/rural status
tabout ind  using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq) pop append
*Population size (households) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq) pop  append

*Population size (individuals) by urban/rural status
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)
tabout ind using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq) pop append
*Population size (individuals) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq) pop append

*Sample size (individuals) by state & urban/rural status
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind hhh_gender poorPPP weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)
tabout ind using "${gsdOutput}/Som_Presentation_0.xls",  c(freq) append 
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls",  c(freq) append 
* Poor/Non-Poor
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)
*Population size (individuals) by Quintiles
tabout poorPPP using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq) pop append

* Count number of EAs:
use "${gsdData}/1-CleanOutput/hh.dta", clear
collapse reg_pess, by(ind ea)
tabout ind using "${gsdOutput}/Som_Presentation_0.xls", c(freq) append


*** Include lower and upper bounds
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_cons], strata(strata)

*Sample size (households) by state & urban/rural status
tabout ind  using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) append
*Sample size (households) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) append

*Population size (households) by urban/rural status
tabout ind  using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) pop append
*Population size (households) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) pop append

*Population size (individuals) by urban/rural status
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)
tabout ind using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) pop  append
*Population size (individuals) by hhh_gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) pop append

*Sample size (individuals) by state & urban/rural statu
clear*
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons ind hhh_gender poorPPP) nogen
tabout ind using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub)  append
tabout hhh_gender using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) append 

* Poor/Non-Poor
use "${gsdData}/1-CleanOutput/hh.dta", clear
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)
*Population size (individuals) by Quintiles
tabout poorPPP  using "${gsdOutput}/Som_Presentation_0.xls", svy c(freq lb ub) pop append





********************************************************************************
*****                                                                      *****
*****                          DEMOGRAPHICS                                *****
*****                                                                      *****
********************************************************************************

**************************** Population Pyramid ********************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear 
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(weight_cons ind hhh_gender quintiles_tc poorPPP) nogen
svyset ea [pweight=weight_cons], strata(strata)
 
*Population age distribution by gender
tabout age_cat_narrow gender using "${gsdOutput}/Som_Presentation_1.xls", svy pop c(freq) f(3) sebnone replace

*Including lower and upper bounds
tabout age_cat_narrow gender using "${gsdOutput}/Som_Presentation_1.xls", svy pop c(freq lb ub) f(3) sebnone append
********************************************************************************
******************** HHH Gender ************************************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata)
* Percent Female HHH 
tabout hhh_gender ind using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col) npos(col) sebnone  replace
* Percent Female HHH  by Quintiles
svyset ea [pweight=weight_cons], strata(strata)
tabout hhh_gender quintiles_tc using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col) npos(col) sebnone append
* Percent Female HHH by poor/nonpoor
tabout hhh_gender poorPPP using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col) npos(col) sebnone append

*** Lower and Upper Bounds
* Percent Female HHH 
svyset ea [pweight=weight_cons], strata(strata)
tabout hhh_gender ind using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col lb ub) npos(col) cibnone  append
* Percent Female HHH  by Quintiles
svyset ea [pweight=weight_cons], strata(strata)
tabout hhh_gender quintiles_tc using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col lb ub) npos(col) cibnone append
* Percent Female HHH by poor/nonpoor
tabout hhh_gender poorPPP using "${gsdOutput}/Som_Presentation_2.xls" , svy percent c(col lb ub) npos(col) cibnone append

********************************************************************************
**************************** HH Size *******************************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 

*Household size by urban/rural/state status
svyset ea [pweight=weight_cons], strata(strata)
tabout ind using "${gsdOutput}/Som_Presentation_3.xls", svy sum c(mean hhsize lb ub) cibnone  f(2)  replace 

*Household size by female/male head
tabout hhh_gender using "${gsdOutput}/Som_Presentation_3.xls", svy sum c(mean hhsize lb ub) cibnone  f(2)  append

*Household size by consumption quintiles
svyset ea [pweight=weight_cons], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Presentation_3.xls", svy sum c(mean hhsize lb ub) cibnone  f(2)  append

*Household size by poor/nonpoor
tabout poorPPP using "${gsdOutput}/Som_Presentation_3.xls", svy sum c(mean hhsize lb ub) cibnone  f(2)  append

********************************************************************************
************ FURTHER STATISTICS OF INTEREST - NOT IN PRESENTATION **************
********************************************************************************

********************************************************************************
******************* Percent Dependents  ****************************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)

*Dependency share by reg status
tabout ind using "${gsdOutput}/Som_Profile_1.xls", svy sum c(mean pdependent) sebnone  f(2) replace

*Dependency share by HHH Gender
tabout hhh_gender using "${gsdOutput}/Som_Profile_1.xls", svy sum c(mean pdependent) sebnone  f(2) append 

*Dependency share by Consumption quintile
gen pweight_cons=weight_cons*hhsize
svyset ea [pweight=pweight_cons], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Profile_1.xls", svy sum c(mean pdependent) sebnone  f(2) append 

*Dependency share by poor/non-poor
tabout poorPPP using "${gsdOutput}/Som_Profile_1.xls", svy sum c(mean pdependent) sebnone  f(2) append 




********************************************************************************
*****                                                                      *****
*****                          POVERTY                                     *****
*****                                                                      *****
********************************************************************************

********************************************************************************
*******************************  Hunger ****************************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
*Hunger by rural urban
svyset ea [pweight=weight_cons], strata(strata)
tabout hunger ind using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col) npos(col) sebnone replace

*Hunger by HHH gender
tabout hunger hhh_gender using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col) npos(col) sebnone append

*Hunger by consumption quintile 
svyset ea [pweight=weight_cons], strata(strata)
tabout hunger quintiles_tc using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col) npos(col) sebnone append

*Hunger by poor/nonpoor
tabout hunger poorPPP using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col) npos(col) sebnone append

*** Inlcuding lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout hunger ind using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col lb ub) npos(col) sebnone append

*Hunger by HHH gender
tabout hunger hhh_gender using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col lb ub) npos(col) sebnone append

*Hunger by consumption quintile
svyset ea [pweight=weight_cons], strata(strata)
tabout hunger quintiles_tc using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col lb ub) npos(col) sebnone append

*Hunger by poor/nonpoor
tabout hunger poorPPP using "${gsdOutput}/Som_Presentation_4.xls", svy percent c(col lb ub) npos(col) sebnone append
********************************************************************************
************************* Poverty Assessment ***********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
* Poverty Headcount Rate
tabout ind using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean poorPPP lb ub) f(3) replace
tabout hhh_gender using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean poorPPP lb ub) f(3) append
tabout remit12m using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean poorPPP lb ub) f(3) append

* Poverty Depth
tabout ind using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pgi lb ub) f(3) npos(col) append
tabout hhh_gender using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pgi lb ub) f(3) npos(col) append
tabout remit12m using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pgi lb ub) f(3) npos(col) append

* Poverty Severity
tabout ind using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pseverity lb ub)f(3) npos(col) append
tabout hhh_gender using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pseverity lb ub) f(3) npos(col) append
tabout remit12m using "${gsdOutput}/Som_Presentation_17.xls" , svy sum c(mean pseverity lb ub) f(3) npos(col) append

use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
* Percentage contribution to poor by each region
tabout ind using "${gsdOutput}/Som_Presentation_18.xls" if poorPPP==1, svy pop c(freq) f(3) replace

* Income distributionb graph
xtile percentiles_tc = tc_imp [pweight=pweight], n(100)
svyset ea [pweight=pweight], strata(strata)
tabout percentiles_tc using "${gsdOutput}/Som_Presentation_18.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) append
* Mean Income by quintile
svyset ea [pweight=pweight], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Presentation_18.xls" , svy sum c(mean tc_imp) f(3) npos(col) append
tabout quintiles_tc ind using "${gsdOutput}/Som_Presentation_18.xls" , svy sum c(mean tc_imp) f(3) npos(col) append

*** Include upper and lower bounds
tabout ind poorPPP using "${gsdOutput}/Som_Presentation_18.xls" , svy pop c(freq lb ub) f(3) append
svyset ea [pweight=pweight], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Presentation_18.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) append
tabout quintiles_tc ind using "${gsdOutput}/Som_Presentation_18.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) append

use "${gsdData}/1-CleanOutput/hh.dta", clear 
drop if missing(weight_cons)
gen pweight = weight_cons * hhsize
*svyset ea [pweight=pweight], strata(strata)
xtile percentiles_tc_mog = tc_imp [pweight=pweight] if ind==1, n(20)
xtile percentiles_tc_urb = tc_imp [pweight=pweight] if ind==2, n(20)
xtile percentiles_tc_rur = tc_imp [pweight=pweight] if ind==3, n(20)
xtile percentiles_tc_idp = tc_imp [pweight=pweight] if ind==4, nq(20) 


tabout percentiles_tc_mog using "${gsdOutput}/Som_Presentation_18mog.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) replace
tabout percentiles_tc_urb using "${gsdOutput}/Som_Presentation_18urb.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) replace
tabout percentiles_tc_rur using "${gsdOutput}/Som_Presentation_18rur.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) replace
tabout percentiles_tc_idp using "${gsdOutput}/Som_Presentation_18idp.xls" , svy sum c(mean tc_imp lb ub) f(3) npos(col) replace



********************************************************************************
*****                                                                      *****
*****                          LABOUR                                      *****
*****                                                                      *****
********************************************************************************

************************* Figure 5 - LFP and basic labour force figures ********
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(quintiles_tc ind weight_cons weight_cons poorPPP) nogen

* Percentage distribution by group
* By rural urban
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d ind using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col) npos(col) sebnone replace
* By Gender
tabout lfp_7d gender using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col) npos(col) sebnone append
* Looking at Youth participation
tabout lfp_7d youth using "${gsdOutput}/Som_Presentation_5.xls" if youth==1, svy percent c(col) npos(col) sebnone append
* Quintiles and poor/NONPOOR
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col) npos(col) sebnone append
tabout lfp_7d poorPPP using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col) npos(col) sebnone append

*** Including lower and upper bounds
* By rural urban
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d ind using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col lb ub) npos(col) sebnone append
* By Gender
tabout lfp_7d gender using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col lb ub) npos(col) sebnone append
* Looking at Youth participation
tabout lfp_7d youth using "${gsdOutput}/Som_Presentation_5.xls" if youth==1, svy percent c(col lb ub) npos(col) sebnone append
* Quintiles and poor/NONPOOR
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col lb ub) npos(col) sebnone append
tabout lfp_7d poorPPP using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy percent c(col lb ub) npos(col) sebnone append


* Absolute size (individuals) in labour force
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d ind using "${gsdOutput}/Som_Presentation_5.xls", svy c(freq) pop append
tabout lfp_7d gender using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy pop c(freq) npos(col) sebnone append
* Looking at Youth participation
tabout lfp_7d youth using "${gsdOutput}/Som_Presentation_5.xls" if youth==1, svy pop c(freq) npos(col) sebnone append
* Quintiles and poor/NONPOOR
svyset ea [pweight=weight_cons], strata(strata)
tabout lfp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy pop c(freq) npos(col) sebnone append
tabout lfp_7d poorPPP using "${gsdOutput}/Som_Presentation_5.xls" if working_age==1, svy c(freq) pop npos(col) sebnone append

*Employed and Unemployed 
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d using "${gsdOutput}/Som_Presentation_5.xls" if lfp_7d==1, svy c(freq) pop npos(col) sebnone append


********************************************************************************
******************* Figure 6 - Employment and Education ************************
********************************************************************************
*Employment statistics across population
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)

* regional split
tabout labor_status_narrow_12m ind using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col) npos(col) sebnone  replace 

* Gender
tabout labor_status_narrow_12m gender using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col) npos(col) sebnone  append 

* Youth
tabout labor_status_narrow_12m youth using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col) npos(col) sebnone  append 

* Quintiles and poor/nonpoor
svyset ea [pweight=weight_cons], strata(strata)
tabout labor_status_narrow_12m quintiles_tc using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col) npos(col) sebnone  append 
tabout labor_status_narrow_12m poorPPP using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col) npos(col) sebnone  append 

*** Include lower and upper bounds
* regional split
svyset ea [pweight=weight_cons], strata(strata)
tabout labor_status_narrow_12m ind using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col lb ub) npos(col) sebnone  append

* Gender
tabout labor_status_narrow_12m gender using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col lb ub) npos(col) sebnone  append 

* Youth
tabout labor_status_narrow_12m youth using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col lb ub) npos(col) sebnone  append 

* Quintiles and poor/nonpoor
svyset ea [pweight=weight_cons], strata(strata)
tabout labor_status_narrow_12m quintiles_tc using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col lb ub) npos(col) sebnone  append 
tabout labor_status_narrow_12m poorPPP using "${gsdOutput}/Som_Presentation_6.xls" , svy percent c(col lb ub) npos(col) sebnone  append 

********************************************************************************
***************** Figure 7 - Inactivity Reasons ********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen

svyset ea [pweight=weight_cons], strata(strata)
tabout inac_narrow gender using "${gsdOutput}/Som_Presentation_7.xls" if working_age==1, svy percent c(col) npos(col) sebnone replace
tabout inac_narrow gender using "${gsdOutput}/Som_Presentation_7.xls" if working_age==1, svy percent c(col lb ub) npos(col) sebnone append

tabout inac_narrow using "${gsdOutput}/Som_Presentation_7.xls" if working_age==1, svy pop c(freq) npos(col) sebnone append

********************************************************************************
****************** Figure 8 - Employment and Unemployment **********************
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen

svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d_d ind using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1 , svy percent c(col) npos(col) sebnone replace
tabout emp_7d_d gender using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d ==1, svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d_d quintiles_tc using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1, svy percent c(col) npos(col) sebnone append
tabout emp_7d_d poorPPP using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1, svy percent c(col) npos(col) sebnone append

* Include lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d_d ind using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1 , svy percent c(col lb ub) npos(col) sebnone append
tabout emp_7d_d gender using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d ==1, svy percent c(col lb ub) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d_d quintiles_tc using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1, svy percent c(col lb ub) npos(col) sebnone append
tabout emp_7d_d poorPPP using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1, svy percent c(col lb ub) npos(col) sebnone append

svyset ea [pweight=weight_cons], strata(strata)
tabout emp_7d_d ind using "${gsdOutput}/Som_Presentation_8.xls" if lfp_7d==1, svy pop c(freq) f(3) append

********************************************************************************
****************** Figure 9 -  Adult Unemployment and Youth Unemployment *******
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen

* Unemployment
svyset ea [pweight=weight_cons], strata(strata)
tabout ad_unemp_7d ind using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col) npos(col) sebnone replace
tabout ad_unemp_7d gender using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout ad_unemp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col) npos(col) sebnone append
tabout ad_unemp_7d poorPPP using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col) npos(col) sebnone append

* Youth Unemployment
svyset ea [pweight=weight_cons], strata(strata)
tabout youth_unemp_7d ind using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24) , svy percent c(col) npos(col) sebnone append
tabout youth_unemp_7d gender using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout youth_unemp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col) npos(col) sebnone append
tabout youth_unemp_7d poorPPP using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col) npos(col) sebnone append

*** Including lower and upper bounds
* Unemployment
svyset ea [pweight=weight_cons], strata(strata)
tabout ad_unemp_7d ind using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col lb ub) npos(col) sebnone append
tabout ad_unemp_7d gender using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col lb ub) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout ad_unemp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col lb ub) npos(col) sebnone append
tabout ad_unemp_7d poorPPP using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 24, 64), svy percent c(col lb ub) npos(col) sebnone append

* Youth Unemployment
svyset ea [pweight=weight_cons], strata(strata)
tabout youth_unemp_7d ind using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24) , svy percent c(col lb ub) npos(col) sebnone append
tabout youth_unemp_7d gender using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col lb ub) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout youth_unemp_7d quintiles_tc using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col lb ub) npos(col) sebnone append
tabout youth_unemp_7d poorPPP using "${gsdOutput}/Som_Presentation_9.xls" if lfp_7d==1 & inrange(age, 15, 24), svy percent c(col lb ub) npos(col) sebnone append

********************************************************************************
****************** Figure 10 -  Hours of Work **********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen

svyset ea [pweight=weight_cons], strata(strata)
tabout emp_hrs_cat using "${gsdOutput}/Som_Presentation_10.xls" , svy percent c(col) npos(col) sebnone replace

********************************************************************************
************************* Status in Employment *********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_status ind using "${gsdOutput}/Som_Presentation_16.xls" , svy percent c(col) npos(col) sebnone replace
tabout emp_status gender using "${gsdOutput}/Som_Presentation_16.xls" , svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_status quintiles_tc using "${gsdOutput}/Som_Presentation_16.xls", svy percent c(col) npos(col) sebnone append
tabout emp_status poorPPP using "${gsdOutput}/Som_Presentation_16.xls", svy percent c(col) npos(col) sebnone append

* Including lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_status ind using "${gsdOutput}/Som_Presentation_16.xls" , svy percent c(col lb ub) npos(col) sebnone append
tabout emp_status gender using "${gsdOutput}/Som_Presentation_16.xls" , svy percent c(col lb ub) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_status quintiles_tc using "${gsdOutput}/Som_Presentation_16.xls", svy percent c(col lb ub) npos(col) sebnone append
tabout emp_status poorPPP using "${gsdOutput}/Som_Presentation_16.xls", svy percent c(col lb ub) npos(col) sebnone append

********************************************************************************
************ FURTHER STATISTICS OF INTEREST - NOT IN PRESENTATION **************
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen


* Employment by Sector
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_sector ind using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone replace
tabout emp_sector gender using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout emp_sector quintiles_tc using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
tabout emp_sector poorPPP using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append

* Employment by Occupation
svyset ea [pweight=weight_cons], strata(strata)
tabout isco ind using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
tabout isco gender using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout isco quintiles_tc using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append 

* Youth Not in Education Employment or Training (NEET)
svyset ea [pweight=weight_cons], strata(strata)
tabout neet ind using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
tabout neet gender using "${gsdOutput}/Som_Presentation_19.xls" , svy percent c(col) npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout neet quintiles_tc using "${gsdOutput}/Som_Presentation_19.xls", svy percent c(col) npos(col) sebnone append

********************************************************************************
******************* Percent Dependents  ****************************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen pweight=weight_cons*hhsize
svyset ea [pweight=pweight], strata(strata)


*Dependency share by reg status
tabout ind using "${gsdOutput}/Som_Presentation_20.xls", svy sum c(mean pdependent) sebnone  f(2) replace

*Dependency share by HHH Gender
tabout hhh_gender using "${gsdOutput}/Som_Presentation_20.xls", svy sum c(mean pdependent) sebnone  f(2) append 

*Dependency share by Consumption quintile
gen pweight_cons=weight_cons*hhsize
svyset ea [pweight=pweight_cons], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Presentation_20.xls", svy sum c(mean pdependent) sebnone  f(2) append 

*Dependency share by poor/non-poor
tabout poorPPP using "${gsdOutput}/Som_Presentation_20.xls", svy sum c(mean pdependent) sebnone  f(2) append 


 


********************************************************************************
*****                                                                      *****
*****                       EDUCATION                                      *****
*****                                                                      *****
********************************************************************************

****************************  Literacy *****************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)

* literacy
tabout literacy ind using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col) ci2col npos(col) sebnone replace
tabout literacy hhh_gender using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col) ci2col npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout literacy quintiles_tc using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col) ci2col npos(col) sebnone append
tabout literacy poorPPP using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col) ci2col npos(col) sebnone append
* Confidence Interval
svyset ea [pweight=weight_cons], strata(strata)
tabout literacy ind using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col lb ub) npos(col) cibnone append
tabout literacy hhh_gender using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col lb ub) npos(col) cibnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout literacy quintiles_tc using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col lb ub) npos(col) cibnone append
tabout literacy poorPPP using "${gsdOutput}/Som_Presentation_11.xls", svy percent c(col lb ub) npos(col) cibnone append


*******************************************************************************
**************************** Education ****************************************
*******************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(ind poorPPP quintiles_tc hhh_gender weight_cons weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)

* Education Level
svyset ea [pweight=weight_cons], strata(strata)
tabout edu_level_broad ind using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col) ci2col npos(col) sebnone replace
tabout edu_level_broad gender using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col) ci2col npos(col) sebnone append
tabout edu_level_broad gen_young using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col) ci2col npos(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout edu_level_broad quintiles_tc using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col) ci2col npos(col) sebnone append
tabout edu_level_broad poorPPP using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col) ci2col npos(col) sebnone append

* Including lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout edu_level_broad ind using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col lb ub) ci2col npos(col) cibnone append
tabout edu_level_broad gender using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col lb ub) ci2col npos(col) cibnone append
tabout edu_level_broad gen_young using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col lb ub) ci2col npos(col) cibnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout edu_level_broad quintiles_tc using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col lb ub) ci2col npos(col) cibnone append
tabout edu_level_broad poorPPP using "${gsdOutput}/Som_Presentation_12.xls", svy percent c(col lb ub) ci2col npos(col) cibnone append


********************************************************************************
************ Primary and Secondary enrollment *********************************
********************************************************************************
* Enrollment rates
use "${gsdData}/1-CleanOutput/hh.dta", clear 
gen pweight = weight_cons * hhsize
svyset ea [pweight=pweight], strata(strata)
tabout ind using "${gsdOutput}/Som_Presentation_21.xls" , svy sum c(mean  penrol) ci2col sebnone replace f(3) 
tabout hhh_gender using "${gsdOutput}/Som_Presentation_21.xls" , svy sum c(mean  penrol) ci2col sebnone append f(3) 

gen pweight_cons = weight_cons * hhsize
svyset ea [pweight=pweight_cons], strata(strata)
tabout quintiles_tc using "${gsdOutput}/Som_Presentation_21.xls" , svy sum c(mean  penrol) ci2col sebnone append f(3)
tabout poorPPP using "${gsdOutput}/Som_Presentation_21.xls" , svy sum c(mean  penrol) ci2col sebnone append f(3) 

* Enrollment by age
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 strata ea block hh using "${gsdData}/1-CleanOutput/hh.dta", assert(match) keepusing(quintiles_tc ind weight_cons weight_cons) nogen
svyset ea [pweight=weight_cons], strata(strata)
gen enrolled = edu_status==1 
tabout age using "${gsdOutput}/Som_Presentation_21.xls" if inrange(age, 6, 18), svy sum c(mean enrolled) ci2col sebnone append f(3) 




********************************************************************************
*****                                                                      *****
*****                    SERVICE PERCEPTION                                *****
*****                                                                      *****
********************************************************************************


********************************************************************************
************************* Access to Amenities **********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear
svyset ea [pweight=weight_cons], strata(strata) 
tabout toilet_type water remit12m ind using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone npos(col) replace
tabout toilet_type water remit12m hhh_gender using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append

svyset ea [pweight=weight_cons], strata(strata)
tabout toilet_type water remit12m quintiles_tc using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append
tabout toilet_type water remit12m poorPPP using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append

svyset ea [pweight=weight_cons], strata(strata) 
tabout treated_water ind using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone npos(col) append
tabout treated_water hhh_gender using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout treated_water quintiles_tc using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append
tabout treated_water poorPPP using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col) sebnone append

*** Including lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata) 
tabout toilet_type water ind using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone npos(col) append
tabout toilet_type water  hhh_gender using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout toilet_type water quintiles_tc using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append
tabout toilet_type water poorPPP using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append

svyset ea [pweight=weight_cons], strata(strata) 
tabout treated_water ind using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone npos(col) append
tabout treated_water hhh_gender using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout treated_water quintiles_tc using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append
tabout treated_water poorPPP using "${gsdOutput}/Som_Presentation_13.xls" , svy percent c(col lb ub) sebnone append

********************************************************************************
************************* Household Perceptions ********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata)
tabout employment_opportunities standard_living ind using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col) sebnone  replace
tabout employment_opportunities standard_living hhh_gender using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col) sebnone  append
svyset ea [pweight=weight_cons], strata(strata)
tabout employment_opportunities standard_living quintiles_tc using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col) sebnone  append
tabout employment_opportunities standard_living poorPPP using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col) sebnone  append

*** Including lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout employment_opportunities standard_living ind using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col lb ub) sebnone  append
tabout employment_opportunities standard_living hhh_gender using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col lb ub) sebnone  append
svyset ea [pweight=weight_cons], strata(strata)
tabout employment_opportunities standard_living quintiles_tc using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col lb ub) sebnone  append
tabout employment_opportunities standard_living poorPPP using "${gsdOutput}/Som_Presentation_14.xls" , svy percent c(col lb ub) sebnone  append

********************************************************************************
************************************* Safety ***********************************
********************************************************************************
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata)
tabout safe_walking travel_other_districts ind using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col) sebnone replace
tabout safe_walking travel_other_districts hhh_gender using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout safe_walking travel_other_districts quintiles_tc using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col) sebnone append
tabout safe_walking travel_other_districts poorPPP using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col) sebnone append

*** Inlcluding lower and upper bounds
svyset ea [pweight=weight_cons], strata(strata)
tabout safe_walking travel_other_districts ind using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col lb ub) sebnone append
tabout safe_walking travel_other_districts hhh_gender using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col lb ub) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout safe_walking travel_other_districts quintiles_tc using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col lb ub) sebnone append
tabout safe_walking travel_other_districts poorPPP using "${gsdOutput}/Som_Presentation_15.xls" , svy percent c(col lb ub) sebnone append

********************************************************************************
************ FURTHER STATISTICS OF INTEREST - NOT IN PRESENTATION **************
********************************************************************************

* Measures of Satisfaction
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata)
tabout health_satisfaction school_satisfaction ind using "${gsdOutput}/Som_Presentation_22.xls" , svy percent c(col) sebnone  replace
tabout health_satisfaction school_satisfaction hhh_gender using "${gsdOutput}/Som_Presentation_22.xls" , svy percent c(col) sebnone  append
svyset ea [pweight=weight_cons], strata(strata)
tabout health_satisfaction school_satisfaction quintiles_tc using "${gsdOutput}/Som_Presentation_22.xls" , svy percent c(col) sebnone  append
tabout health_satisfaction school_satisfaction poorPPP using "${gsdOutput}/Som_Presentation_22.xls" , svy percent c(col) sebnone  append


* Trust, police and government perception
use "${gsdData}/1-CleanOutput/hh.dta", clear 
svyset ea [pweight=weight_cons], strata(strata)
tabout trust_people police_competence travel_other_districts improve_community agent_of_change ind using "${gsdOutput}/Som_Presentation_23.xls" , svy percent c(col) sebnone append
tabout trust_people police_competence travel_other_districts improve_community agent_of_change hhh_gender using "${gsdOutput}/Som_Presentation_23.xls" , svy percent c(col) sebnone append
svyset ea [pweight=weight_cons], strata(strata)
tabout trust_people police_competence travel_other_districts improve_community agent_of_change quintiles_tc using "${gsdOutput}/Som_Presentation_23.xls" , svy percent c(col) sebnone append
tabout trust_people police_competence travel_other_districts improve_community agent_of_change poorPPP using "${gsdOutput}/Som_Presentation_23.xls" , svy percent c(col) sebnone append




********************************************************************************
*****                                                                      *****
*****                        APPEND                                        *****
*****                                                                      *****
********************************************************************************


* Put all created sheets into one excel document
foreach i of numlist 0/18 21 {
	insheet using "${gsdOutput}/Som_Presentation_`i'.xls", clear nonames tab
	export excel using "${gsdOutput}/Som_Overview_forpres_v20.xls", sheetreplace sheet("Raw_Figure_`i'") 
}
local lis= "mog urb rur idp"
foreach k of local lis {
	insheet using "${gsdOutput}/Som_Presentation_18`k'.xls", clear nonames tab
	export excel using "${gsdOutput}/Som_Overview_forpres_v20.xls", sheetreplace sheet("Raw_Figure_18`k'") 
}
